==> MailScanner-4.57.4-1.rpm.tar.gz: MailScanner-4.57.4-1/install.sh <==
#!/bin/sh

# Wait for n seconds, or 1 second if they ran me with "fast" on the command-line
timewait () {
  DELAY=$1
  if [ "x$FAST" = "x" ]; then
    sleep $DELAY
  else
    sleep 1
  fi
}


echo
if [ -x /bin/rpmbuild ]; then
  RPMBUILD=/bin/rpmbuild
elif [ -x /usr/bin/rpmbuild ]; then
  RPMBUILD=/usr/bin/rpmbuild
elif [ -x /bin/rpm ]; then
  RPMBUILD=/bin/rpm
elif [ -x /usr/bin/rpm ]; then
  RPMBUILD=/usr/bin/rpm
else
  echo I cannot find any rpm or rpmbuild command on your path.
  echo Please check you are definitely using an RPM-based system.
  echo If you are, then please install the RPMs called rpm and
  echo rpm-build, then try running this script again.
  echo
  exit 1
fi

echo
if [ -x /bin/patch -o -x /usr/bin/patch ]; then
  echo Good. You have the patch command.
else
  echo You need to install the patch command from your Linux distribution.
  echo Once you have done that, please try running this script again.
  exit 1
fi

# Check that /usr/src/redhat exists
echo
if [ -d /usr/src/redhat ]; then
  echo Good, you have /usr/src/redhat in place.
  RPMROOT=/usr/src/redhat
elif [ -d /usr/src/RPM ]; then
  echo Okay, you have /usr/src/RPM.
  RPMROOT=/usr/src/RPM
elif [ -d /usr/src/packages ]; then
  echo Okay, you have /usr/src/packages.
  RPMROOT=/usr/src/packages
else
  echo Your /usr/src/redhat, /usr/src/RPM or /usr/src/packages
  echo tree is missing.
  echo If you have access to an RPM called rpm-build or rpmbuild
  echo then install it first and come back and try again.
  echo
  exit 1
fi

# Fix up 2 problems with Mandrake
if [ -f /etc/redhat-release  ];
then
  if egrep -qi 'mandrake|mandriva' /etc/redhat-release
  then
    echo I think you are running on Mandrake or Mandriva.
    echo There are 2 problems I need to correct.
    # Mandrake only
    DONT_CLEAN_PERL=1
    export DONT_CLEAN_PERL
    if [ -f /usr/lib/rpm/brp-compress ]; then
      perl -pi.bak -e 's/^COMPRESS=(.*)-n/COMPRESS=$1/' /usr/lib/rpm/brp-compress
      timewait 1
      echo Done.
    else
      echo Failed to find /usr/lib/rpm/brp-compress.
      echo Have you installed the rpm-build package\?
      echo You need to do that first or I cannot do anything.
      exit 1
    fi
    timewait 5
  fi
fi

# Ensure that the RPM macro
# %_unpackaged_files_terminate_build 1
# is set. Otherwise package building will fail.
echo
if grep -qs '%_unpackaged_files_terminate_build[ 	][ 	]*0' ~/.rpmmacros
then
  echo Good, unpackaged files will not break the build process.
else
  echo Writing a .rpmmacros file in your home directory to stop
  echo unpackaged files breaking the build process.
  echo You can delete it once MailScanner is installed if you want to.
  echo '%_unpackaged_files_terminate_build 0' >> ~/.rpmmacros
  echo
  timewait 10
fi
if grep -qs '%__perl_requires[ 	][ 	]*%{!?nil}' ~/.rpmmacros
then
  echo Good, far-too-clever Perl requirements will be ignored.
else
  echo Adding to the .rpmmacros file in your home directory to stop
  echo RPM trying to be too clever finding Perl requirements.
  echo You can delete it once MailScanner is installed if you want to.
  echo '%__perl_requires %{!?nil}' >> ~/.rpmmacros
  echo
  timewait 10
fi
timewait 5

# Process the command-line options
# This is blatantly plagiarised from the typical "./configure" produced by
# "autoconf".  If we need to get more complicated, then we should probably
# migrate towards using "autoconf" itself.  (Hence not optimising this part, to
# preserve resemblance and encourage compability with "autoconf" conventions.)

as_me=`(basename "$0") 2>/dev/null`

ac_init_help=
ignoreperl=
nodeps=
fast=
for ac_option
do
  ac_optarg=`expr "x$ac_option" : 'x[^=]*=\(.*\)'`

  case $ac_option in
  ignore-perl)
    ignoreperl=$ac_option ;;

  nodeps)
    nodeps=$ac_option ;;

  fast)
    fast=$ac_option ;;

  --help | -h)
    ac_init_help=long ;;

  -*) { echo "$as_me: error: unrecognized option: $ac_option
Try \`$0 --help' for more information." >&2
   { (exit 1); exit 1; }; }
    ;;

  *) { echo "$as_me: error: unrecognized argument: $ac_option
Try \`$0 --help' for more information." >&2
   { (exit 1); exit 1; }; }
    ;;

  esac
done

if test "$ac_init_help" = "long"; then
    cat <<_ACEOF
Usage: $0 [OPTION]... [VAR=VALUE]...

  -h, --help            display this help and exit
  nodeps                ignore dependencies when installing MailScanner
  ignore-perl           ignore perl versions check
  fast                  do not wait for long during installation

_ACEOF

fi

test -n "$ac_init_help" && exit 0

# Set variables for later use
IGNORE_PERL=$ignoreperl
NODEPS=$nodeps
FAST=$fast

# Check they don't have 2 Perl installations, this will cause all sorts
# of grief later.
echo
if [ \! "x$IGNORE_PERL" = "xignore-perl" ] ; then
  if [ -x /usr/bin/perl -a -f /usr/local/bin/perl -a -x /usr/local/bin/perl ] ;
  then
    echo You appear to have 2 versions of Perl installed,
    echo the normal one in /usr/bin and one in /usr/local.
    echo This often happens if you have used CPAN to install modules.
    PERL1=`ls -l /usr/bin/perl | awk '{ print $NF }'`
    PERL2=`ls -l /usr/local/bin/perl | awk '{ print $NF }'`
    if [ "x$PERL1" = "x$PERL2" ]; then
      echo Fortunately they both point to the same place, so you are fine.
      sleep 2
    else
      echo I strongly advise you remove all traces of perl from
      echo within /usr/local and then run this script again.
      echo
      echo If you do not want to do that, and really want to continue,
      echo then you will need to run this script as
      echo '        ./install.sh ignore-perl'
      echo
      exit 1
    fi
  else
    echo Good, you appear to only have 1 copy of Perl installed.
  fi
fi
PERL="/usr/bin/perl"

# Check to see if they want to ignore dependencies in the final
# MailScanner RPM install.
if [ \! "x$NODEPS" = "x" ]
then
  NODEPS='--nodeps'
else
  NODEPS=
fi

# Check that they aren't on a RaQ3 with a broken copy of Perl 5.005003.
if [ -d /usr/lib/perl5/5.00503/i386-linux/CORE ]; then
  echo
  echo I think you are running Perl 5.00503.
  echo Ensuring that you have all the header files that are needed
  echo to build HTML-Parser which is used by both MailScanner and
  echo SpamAssassin.

  touch /usr/lib/perl5/5.00503/i386-linux/CORE/opnames.h
  touch /usr/lib/perl5/5.00503/i386-linux/CORE/perlapi.h
  touch /usr/lib/perl5/5.00503/i386-linux/CORE/utf8.h
  touch /usr/lib/perl5/5.00503/i386-linux/CORE/warnings.h
fi

# Check that they aren't missing pod2text but have pod2man.
if [ -x /usr/bin/pod2man -a \! -x /usr/bin/pod2text ] ; then
  echo
  echo You appear to have pod2man but not pod2text.
  echo Creating pod2text for you.
  ln -s pod2man /usr/bin/pod2text
fi

# Check they have the development tools installed on SuSE
if [ -f /etc/SuSE-release -o -f /etc/redhat-release ]; then
  echo
  echo I think you are running on RedHat Linux, Mandrake Linux or SuSE Linux.
  GCC=gcc
  if [ -f /etc/redhat-release ] && fgrep -q ' 6.' /etc/redhat-release ; then
      # RedHat used egcs in RedHat 6 and not gcc
      GCC=egcs
  fi
  if rpm -q binutils glibc-devel $GCC make >/dev/null 2>&1 ; then
    echo Good, you appear to have the basic development tools installed.
    timewait 5
  else
    echo You must have the following RPM packages installed before
    echo you try and do anything else:
    echo '       binutils glibc-devel' $GCC 'make'
    echo You are missing at least 1 of these.
    echo Please install them all
    echo '(Read the manuals if you do not know how to do this).'
    echo Then come back and run this install.sh script again.
    echo
    exit 1
  fi
fi

echo
echo This script will pause for a few seconds after each major step,
echo so do not worry if it appears to stop for a while.
echo If you want it to stop so you can scroll back through the output
echo then press Ctrl-S to stop the output and Ctrl-Q to start it again.
echo
timewait 10

echo
echo If this fails due to dependency checks, and you wish to ignore
echo these problems, you can run
echo '    ./install.sh nodeps'
timewait 5

echo
echo Setting Perl5 search path
echo
PERL5LIB=`perl -V | grep site_perl | tr -d ' ' | tr '\n' ':'`
export PERL5LIB

# Work out the architecture we are building for
BUILDARCH=`rpm -q --queryformat='%{ARCH}' perl`
# Fedora Core 3 reports both i386 and x86_64, so use x86_64
if [ $BUILDARCH = 'i386x86_64' -o $BUILDARCH = 'x86_64i386' ]; then
  BUILDARCH='x86_64'
fi
export BUILDARCH
echo I think your system will build architecture-dependent modules for $BUILDARCH
echo
echo Rebuilding all the Perl RPMs for your version of Perl
echo
timewait 5

while read MODNAME MODFILE VERS BUILD ARC
do
  # Reset the architecture to what it really is
  if [ "x$ARC" = "xarch" ]; then
    ARC=$BUILDARCH
  fi

  # If the module version is already installed, go onto the next one
  # (unless it is MIME-tools which is always rebuilt.
  if ./CheckModuleVersion ${MODNAME} ${VERS} && [ "x$MODNAME" \!= "xMIME::Base64" ]; then
    echo Oh good, module ${MODNAME} version ${VERS} is already installed.
    echo
    timewait 5
  else
    FILEPREFIX=perl-${MODFILE}-${VERS}-${BUILD}
    # Need to install my customised version of MIME-Base64
    if [ "x${MODFILE}" = "xMIME-Base64" ]; then
      FILEPREFIX=MailScanner-${FILEPREFIX}
    fi
    echo Attempting to build and install ${FILEPREFIX}
    if [ -f ${FILEPREFIX}.src.rpm ]; then
      if [ "x${MODFILE}" = "xCompress-Zlib" ]; then
        echo Detected Compress-Zlib, building appropriately...
        PERL5LIB= $RPMBUILD --rebuild ${FILEPREFIX}.src.rpm
      else
        $RPMBUILD --rebuild ${FILEPREFIX}.src.rpm
      fi
      timewait 10
      echo
      echo
      echo
    else
      echo Missing file ${FILEPREFIX}.src.rpm. Are you in the right directory\?
      timewait 10
      echo
    fi
    if [ -f ${RPMROOT}/RPMS/${ARC}/${FILEPREFIX}.${ARC}.rpm ]; then
      echo
      echo Do not worry too much about errors from the next command.
      echo It is quite likely that some of the Perl modules are
      echo already installed on your system.
      echo
      echo The important ones are HTML-Parser and MIME-tools.
      echo
      timewait 10
      if [ -f /etc/SuSE-release -a "x${MODFILE}" = "xMIME-tools" ];
      then
        echo As you are running SuSE, I have to force installation of
        echo the MIME-tools package to ensure you have all the security
        echo patches applied.
        rpm -Uvh --force ${NODEPS} ${RPMROOT}/RPMS/${ARC}/${FILEPREFIX}.${ARC}.rpm
      elif [ "x${MODFILE}" = "xMIME-Base64" ]; then
        echo I have to force installation of MIME-Base64. Sorry.
        rpm -Uvh --force ${NODEPS} ${RPMROOT}/RPMS/${ARC}/${FILEPREFIX}.${ARC}.rpm
      elif [ "x${MODFILE}" = "xDBI" ]; then
        echo I have to force installation of DBI. Sorry.
        rpm -Uvh --force ${NODEPS} ${RPMROOT}/RPMS/${ARC}/${FILEPREFIX}.${ARC}.rpm
      elif [ "x${MODFILE}" = "xTimeDate" ]; then
        echo I have to force installation of TimeDate. Sorry.
        rpm -Uvh --force ${NODEPS} ${RPMROOT}/RPMS/${ARC}/${FILEPREFIX}.${ARC}.rpm
      elif [ "x${MODFILE}" = "xSys-Syslog" ]; then
        echo I have to force installation of Sys-Syslog. Sorry.
        rpm -Uvh --force ${NODEPS} ${RPMROOT}/RPMS/${ARC}/${FILEPREFIX}.${ARC}.rpm
      else
        rpm -Uvh ${NODEPS} ${RPMROOT}/RPMS/${ARC}/${FILEPREFIX}.${ARC}.rpm
      fi
      timewait 10
      echo
      echo
      echo
    else
      echo Missing file ${RPMROOT}/RPMS/${ARC}/${FILEPREFIX}.${ARC}.rpm.
      echo Maybe it did not build correctly\?
      timewait 10
      echo
    fi
  fi
done << EOF
ExtUtils::MakeMaker ExtUtils-MakeMaker 6.30 1	noarch
Net::CIDR	Net-CIDR	0.10	1	noarch
IsABundle	IO-stringy	2.108	1	noarch
MIME::Base64	MIME-Base64	3.05	5	arch
IsABundle	TimeDate	1.16	3	noarch
IsABundle	MailTools	1.71	1	noarch
File::Spec	File-Spec	0.82	1	noarch
File::Temp	File-Temp	0.16	1	noarch
HTML::Tagset	HTML-Tagset	3.03	1	noarch
HTML::Parser	HTML-Parser	3.54	1	arch
Convert::BinHex	Convert-BinHex	1.119	2	noarch
IsABundle	MIME-tools	5.420	1	noarch
Convert::TNEF	Convert-TNEF	0.17	1	noarch
Compress::Zlib	Compress-Zlib	1.41	1	arch
Archive::Zip	Archive-Zip	1.16	1	noarch
DBI		DBI		1.50	2	noarch
DBD::SQLite	DBD-SQLite	1.12	1	noarch
Getopt::Long	Getopt-Long	2.35	1	noarch
Time::HiRes	Time-HiRes	1.86	1	noarch
Filesys::Df     Filesys-Df 	0.90	1	noarch
Net::IP		Net-IP		1.24	1	noarch
Sys::Hostname::Long Sys-Hostname-Long 1.4 1	noarch
Sys::Syslog	Sys-Syslog	0.18	1	noarch
EOF

# Undo the temporary change to /usr/lib/rpm/perl.req
if [ -f /usr/lib/rpm/perl.req.MSoriginal ];
then
  mv -f /usr/lib/rpm/perl.req.MSoriginal /usr/lib/rpm/perl.req
fi

echo
echo Installing tnef decoder
echo

rpm -Uvh tnef*i386.rpm

echo
echo Now to install MailScanner itself.
echo
echo NOTE: If you get lots of errors here, run the install.sh script
echo NOTE: again with the command \"./install.sh nodeps\"
echo
timewait 10

if [ -d /usr/local/MailScanner ] ; then
  echo
  echo
  echo Please remember to kill all the old mailscanner version 3
  echo processes before you start the new version.
  echo
fi

rpm -Uvh ${NODEPS} mailscanner*noarch.rpm

rpmnew=`ls /usr/lib/MailScanner/*rpmnew 2>/dev/null | wc -w`
if [ $rpmnew -ne 0 ]; then
  echo
  echo 'There are new *.rpmnew files in /usr/lib/MailScanner.'
  echo 'You should rename each of these over the top of the old'
  echo 'version of each file, but remember to copy any changes'
  echo 'you have made to the old versions.'
  echo
fi

sleep 5
echo '----------------------------------------------------------'
echo 'Please buy the MailScanner book from www.mailscanner.info!'
echo 'It is a very useful administration guide and introduction'
echo 'to MailScanner. All the proceeds go directly to making'
echo 'MailScanner a better supported package than it is today.'
echo

==> MailScanner-4.58.9-1.rpm.tar.gz: MailScanner-4.58.9-1/install.sh <==
#!/bin/sh

# Wait for n seconds, or 1 second if they ran me with "fast" on the command-line
timewait () {
  DELAY=$1
  if [ "x$FAST" = "x" ]; then
    sleep $DELAY
  else
    sleep 1
  fi
}


echo
if [ -x /bin/rpmbuild ]; then
  RPMBUILD=/bin/rpmbuild
elif [ -x /usr/bin/rpmbuild ]; then
  RPMBUILD=/usr/bin/rpmbuild
elif [ -x /bin/rpm ]; then
  RPMBUILD=/bin/rpm
elif [ -x /usr/bin/rpm ]; then
  RPMBUILD=/usr/bin/rpm
else
  echo I cannot find any rpm or rpmbuild command on your path.
  echo Please check you are definitely using an RPM-based system.
  echo If you are, then please install the RPMs called rpm and
  echo rpm-build, then try running this script again.
  echo
  exit 1
fi

echo
if [ -x /bin/patch -o -x /usr/bin/patch ]; then
  echo Good. You have the patch command.
else
  echo You need to install the patch command from your Linux distribution.
  echo Once you have done that, please try running this script again.
  exit 1
fi

# Check that /usr/src/redhat exists
echo
if [ -d /usr/src/redhat ]; then
  echo Good, you have /usr/src/redhat in place.
  RPMROOT=/usr/src/redhat
elif [ -d /usr/src/RPM ]; then
  echo Okay, you have /usr/src/RPM.
  RPMROOT=/usr/src/RPM
elif [ -d /usr/src/packages ]; then
  echo Okay, you have /usr/src/packages.
  RPMROOT=/usr/src/packages
else
  echo Your /usr/src/redhat, /usr/src/RPM or /usr/src/packages
  echo tree is missing.
  echo If you have access to an RPM called rpm-build or rpmbuild
  echo then install it first and come back and try again.
  echo
  exit 1
fi

# Fix up 2 problems with Mandriva
if [ -f /etc/redhat-release  ];
then
  if egrep -qi 'mandrake|mandriva' /etc/redhat-release
  then
    echo I think you are running on Mandrake or Mandriva.
    echo There are 2 problems I need to correct.
    # Mandriva only
    DONT_CLEAN_PERL=1
    export DONT_CLEAN_PERL
    if [ -f /usr/lib/rpm/brp-compress ]; then
      perl -pi.bak -e 's/^COMPRESS=(.*)-n/COMPRESS=$1/' /usr/lib/rpm/brp-compress
      timewait 1
      echo Done.
    else
      echo Failed to find /usr/lib/rpm/brp-compress.
      echo Have you installed the rpm-build package\?
      echo You need to do that first or I cannot do anything.
      exit 1
    fi
    timewait 5
  fi
fi

# Ensure that the RPM macro
# %_unpackaged_files_terminate_build 1
# is set. Otherwise package building will fail.
echo
if grep -qs '%_unpackaged_files_terminate_build[ 	][ 	]*0' ~/.rpmmacros
then
  echo Good, unpackaged files will not break the build process.
else
  echo Writing a .rpmmacros file in your home directory to stop
  echo unpackaged files breaking the build process.
  echo You can delete it once MailScanner is installed if you want to.
  echo '%_unpackaged_files_terminate_build 0' >> ~/.rpmmacros
  echo
  timewait 10
fi
if grep -qs '%__perl_requires[ 	][ 	]*%{!?nil}' ~/.rpmmacros
then
  echo Good, far-too-clever Perl requirements will be ignored.
else
  echo Adding to the .rpmmacros file in your home directory to stop
  echo RPM trying to be too clever finding Perl requirements.
  echo You can delete it once MailScanner is installed if you want to.
  echo '%__perl_requires %{!?nil}' >> ~/.rpmmacros
  echo
  timewait 10
fi
timewait 5

# Process the command-line options
# This is blatantly plagiarised from the typical "./configure" produced by
# "autoconf".  If we need to get more complicated, then we should probably
# migrate towards using "autoconf" itself.  (Hence not optimising this part, to
# preserve resemblance and encourage compability with "autoconf" conventions.)

as_me=`(basename "$0") 2>/dev/null`

ac_init_help=
ignoreperl=
nodeps=
fast=
for ac_option
do
  ac_optarg=`expr "x$ac_option" : 'x[^=]*=\(.*\)'`

  case $ac_option in
  ignore-perl)
    ignoreperl=$ac_option ;;

  nodeps)
    nodeps=$ac_option ;;

  fast)
    fast=$ac_option ;;

  --help | -h)
    ac_init_help=long ;;

  -*) { echo "$as_me: error: unrecognized option: $ac_option
Try \`$0 --help' for more information." >&2
   { (exit 1); exit 1; }; }
    ;;

  *) { echo "$as_me: error: unrecognized argument: $ac_option
Try \`$0 --help' for more information." >&2
   { (exit 1); exit 1; }; }
    ;;

  esac
done

if test "$ac_init_help" = "long"; then
    cat <<_ACEOF
Usage: $0 [OPTION]... [VAR=VALUE]...

  -h, --help            display this help and exit
  nodeps                ignore dependencies when installing MailScanner
  ignore-perl           ignore perl versions check
  fast                  do not wait for long during installation

_ACEOF

fi

test -n "$ac_init_help" && exit 0

# Set variables for later use
IGNORE_PERL=$ignoreperl
NODEPS=$nodeps
FAST=$fast

# Check they don't have 2 Perl installations, this will cause all sorts
# of grief later.
echo
if [ \! "x$IGNORE_PERL" = "xignore-perl" ] ; then
  if [ -x /usr/bin/perl -a -f /usr/local/bin/perl -a -x /usr/local/bin/perl ] ;
  then
    echo You appear to have 2 versions of Perl installed,
    echo the normal one in /usr/bin and one in /usr/local.
    echo This often happens if you have used CPAN to install modules.
    PERL1=`ls -l /usr/bin/perl | awk '{ print $NF }'`
    PERL2=`ls -l /usr/local/bin/perl | awk '{ print $NF }'`
    if [ "x$PERL1" = "x$PERL2" ]; then
      echo Fortunately they both point to the same place, so you are fine.
      sleep 2
    else
      echo I strongly advise you remove all traces of perl from
      echo within /usr/local and then run this script again.
      echo
      echo If you do not want to do that, and really want to continue,
      echo then you will need to run this script as
      echo '        ./install.sh ignore-perl'
      echo
      exit 1
    fi
  else
    echo Good, you appear to only have 1 copy of Perl installed.
  fi
fi
PERL="/usr/bin/perl"

# Check to see if they want to ignore dependencies in the final
# MailScanner RPM install.
if [ \! "x$NODEPS" = "x" ]
then
  NODEPS='--nodeps'
else
  NODEPS=
fi

# Check that they aren't on a RaQ3 with a broken copy of Perl 5.005003.
if [ -d /usr/lib/perl5/5.00503/i386-linux/CORE ]; then
  echo
  echo I think you are running Perl 5.00503.
  echo Ensuring that you have all the header files that are needed
  echo to build HTML-Parser which is used by both MailScanner and
  echo SpamAssassin.

  touch /usr/lib/perl5/5.00503/i386-linux/CORE/opnames.h
  touch /usr/lib/perl5/5.00503/i386-linux/CORE/perlapi.h
  touch /usr/lib/perl5/5.00503/i386-linux/CORE/utf8.h
  touch /usr/lib/perl5/5.00503/i386-linux/CORE/warnings.h
fi

# Check that they aren't missing pod2text but have pod2man.
if [ -x /usr/bin/pod2man -a \! -x /usr/bin/pod2text ] ; then
  echo
  echo You appear to have pod2man but not pod2text.
  echo Creating pod2text for you.
  ln -s pod2man /usr/bin/pod2text
fi

# Check they have the development tools installed on SuSE
if [ -f /etc/SuSE-release -o -f /etc/redhat-release ]; then
  echo
  echo I think you are running on RedHat Linux, Mandriva Linux or SuSE Linux.
  GCC=gcc
  if [ -f /etc/redhat-release ] && fgrep -q ' 6.' /etc/redhat-release ; then
      # RedHat used egcs in RedHat 6 and not gcc
      GCC=egcs
  fi
  if rpm -q binutils glibc-devel $GCC make >/dev/null 2>&1 ; then
    echo Good, you appear to have the basic development tools installed.
    timewait 5
  else
    echo You must have the following RPM packages installed before
    echo you try and do anything else:
    echo '       binutils glibc-devel' $GCC 'make'
    echo You are missing at least 1 of these.
    echo Please install them all
    echo '(Read the manuals if you do not know how to do this).'
    echo Then come back and run this install.sh script again.
    echo
    exit 1
  fi
fi

echo
echo This script will pause for a few seconds after each major step,
echo so do not worry if it appears to stop for a while.
echo If you want it to stop so you can scroll back through the output
echo then press Ctrl-S to stop the output and Ctrl-Q to start it again.
echo
timewait 10

echo
echo If this fails due to dependency checks, and you wish to ignore
echo these problems, you can run
echo '    ./install.sh nodeps'
timewait 5

echo
echo Setting Perl5 search path
echo
PERL5LIB=`perl -V | grep site_perl | tr -d ' ' | tr '\n' ':'`
export PERL5LIB

# Work out the architecture we are building for
BUILDARCH=`rpm -q --queryformat='%{ARCH}' perl`
# Fedora Core 3 reports both i386 and x86_64, so use x86_64
if [ $BUILDARCH = 'i386x86_64' -o $BUILDARCH = 'x86_64i386' ]; then
  BUILDARCH='x86_64'
fi
export BUILDARCH
echo I think your system will build architecture-dependent modules for $BUILDARCH
echo
echo Rebuilding all the Perl RPMs for your version of Perl
echo
timewait 5

while read MODNAME MODFILE VERS BUILD ARC
do
  # Reset the architecture to what it really is
  if [ "x$ARC" = "xarch" ]; then
    ARC=$BUILDARCH
  fi

  # If the module version is already installed, go onto the next one
  # (unless it is MIME-tools which is always rebuilt.
  if ./CheckModuleVersion ${MODNAME} ${VERS} && [ "x$MODNAME" \!= "xMIME::Base64" ]; then
    echo Oh good, module ${MODNAME} version ${VERS} is already installed.
    echo
    timewait 5
  else
    FILEPREFIX=perl-${MODFILE}-${VERS}-${BUILD}
    # Need to install my customised version of MIME-Base64
    if [ "x${MODFILE}" = "xMIME-Base64" ]; then
      FILEPREFIX=MailScanner-${FILEPREFIX}
    fi
    echo Attempting to build and install ${FILEPREFIX}
    if [ -f ${FILEPREFIX}.src.rpm ]; then
      if [ "x${MODFILE}" = "xCompress-Zlib" ]; then
        echo Detected Compress-Zlib, building appropriately...
        PERL5LIB= $RPMBUILD --rebuild ${FILEPREFIX}.src.rpm
      else
        $RPMBUILD --rebuild ${FILEPREFIX}.src.rpm
      fi
      timewait 10
      echo
      echo
      echo
    else
      echo Missing file ${FILEPREFIX}.src.rpm. Are you in the right directory\?
      timewait 10
      echo
    fi
    if [ -f ${RPMROOT}/RPMS/${ARC}/${FILEPREFIX}.${ARC}.rpm ]; then
      echo
      echo Do not worry too much about errors from the next command.
      echo It is quite likely that some of the Perl modules are
      echo already installed on your system.
      echo
      echo The important ones are HTML-Parser and MIME-tools.
      echo
      timewait 10
      if [ -f /etc/SuSE-release -a "x${MODFILE}" = "xMIME-tools" ];
      then
        echo As you are running SuSE, I have to force installation of
        echo the MIME-tools package to ensure you have all the security
        echo patches applied.
        rpm -Uvh --force ${NODEPS} ${RPMROOT}/RPMS/${ARC}/${FILEPREFIX}.${ARC}.rpm
      elif [ "x${MODFILE}" = "xMIME-Base64" ]; then
        echo I have to force installation of MIME-Base64. Sorry.
        rpm -Uvh --force ${NODEPS} ${RPMROOT}/RPMS/${ARC}/${FILEPREFIX}.${ARC}.rpm
      elif [ "x${MODFILE}" = "xDBI" ]; then
        echo I have to force installation of DBI. Sorry.
        rpm -Uvh --force ${NODEPS} ${RPMROOT}/RPMS/${ARC}/${FILEPREFIX}.${ARC}.rpm
      elif [ "x${MODFILE}" = "xTimeDate" ]; then
        echo I have to force installation of TimeDate. Sorry.
        rpm -Uvh --force ${NODEPS} ${RPMROOT}/RPMS/${ARC}/${FILEPREFIX}.${ARC}.rpm
      elif [ "x${MODFILE}" = "xSys-Syslog" ]; then
        echo I have to force installation of Sys-Syslog. Sorry.
        rpm -Uvh --force ${NODEPS} ${RPMROOT}/RPMS/${ARC}/${FILEPREFIX}.${ARC}.rpm
      else
        rpm -Uvh ${NODEPS} ${RPMROOT}/RPMS/${ARC}/${FILEPREFIX}.${ARC}.rpm
      fi
      timewait 10
      echo
      echo
      echo
    else
      echo Missing file ${RPMROOT}/RPMS/${ARC}/${FILEPREFIX}.${ARC}.rpm.
      echo Maybe it did not build correctly\?
      timewait 10
      echo
    fi
  fi
done << EOF
ExtUtils::MakeMaker ExtUtils-MakeMaker 6.30 1	noarch
Net::CIDR	Net-CIDR	0.10	1	noarch
IsABundle	IO-stringy	2.108	1	noarch
MIME::Base64	MIME-Base64	3.05	5	arch
IsABundle	TimeDate	1.16	3	noarch
IsABundle	MailTools	1.71	1	noarch
File::Spec	File-Spec	0.82	1	noarch
File::Temp	File-Temp	0.16	1	noarch
HTML::Tagset	HTML-Tagset	3.03	1	noarch
HTML::Parser	HTML-Parser	3.54	1	arch
Convert::BinHex	Convert-BinHex	1.119	2	noarch
IsABundle	MIME-tools	5.420	1	noarch
Convert::TNEF	Convert-TNEF	0.17	1	noarch
Compress::Zlib	Compress-Zlib	1.41	1	arch
Archive::Zip	Archive-Zip	1.16	1	noarch
DBI		DBI		1.50	2	noarch
DBD::SQLite	DBD-SQLite	1.12	1	noarch
Getopt::Long	Getopt-Long	2.35	1	noarch
Time::HiRes	Time-HiRes	1.86	1	noarch
Filesys::Df     Filesys-Df 	0.90	1	noarch
Net::IP		Net-IP		1.24	1	noarch
Sys::Hostname::Long Sys-Hostname-Long 1.4 1	noarch
Sys::Syslog	Sys-Syslog	0.18	1	noarch
EOF

# Undo the temporary change to /usr/lib/rpm/perl.req
if [ -f /usr/lib/rpm/perl.req.MSoriginal ];
then
  mv -f /usr/lib/rpm/perl.req.MSoriginal /usr/lib/rpm/perl.req
fi

echo
echo Installing tnef decoder
echo

rpm -Uvh tnef*i386.rpm

echo
echo Now to install MailScanner itself.
echo
echo NOTE: If you get lots of errors here, run the install.sh script
echo NOTE: again with the command \"./install.sh nodeps\"
echo
timewait 10

if [ -d /usr/local/MailScanner ] ; then
  echo
  echo
  echo Please remember to kill all the old mailscanner version 3
  echo processes before you start the new version.
  echo
fi

rpm -Uvh ${NODEPS} mailscanner*noarch.rpm

rpmnew=`ls /usr/lib/MailScanner/*rpmnew 2>/dev/null | wc -w`
if [ $rpmnew -ne 0 ]; then
  echo
  echo 'There are new *.rpmnew files in /usr/lib/MailScanner.'
  echo 'You should rename each of these over the top of the old'
  echo 'version of each file, but remember to copy any changes'
  echo 'you have made to the old versions.'
  echo
fi

sleep 5
echo '----------------------------------------------------------'
echo 'Please buy the MailScanner book from www.mailscanner.info!'
echo 'It is a very useful administration guide and introduction'
echo 'to MailScanner. All the proceeds go directly to making'
echo 'MailScanner a better supported package than it is today.'
echo
